##  Scope of Integration: Data Synchronization Between Collibra and SAP LeanIX
Collibra EDC (Enterprise Data Catalog) application gives a comprehensive overview of the metadata / all data assets in the organization, making it convenient for users to find, describe, govern, and manage data.
![Scope of the Integration Between SAP LeanIX and Collibra](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274e27387a441014ac85e4c232fa13f0_LowRes.png)
Scope of the Integration Between SAP LeanIX and Collibra
The integration between SAP LeanIX and Collibra provides the following:
  * Synchronize conceptual data layer from Collibra Data Catalog to data object fact sheets in SAP LeanIX. To learn more, see [Conceptual Data Layer Mapping from Collibra to SAP LeanIX](https://help.sap.com/docs/leanix/ea/conceptual-data-layer-mapping-from-collibra-to-sap-leanix?locale=en-US&state=PRODUCTION&version=CLOUD "Configure the mapping of the conceptual data layer from Collibra to the SAP LeanIX data object fact sheet, including assets, fields, responsibilities, and relations.").
  * Synchronize names, data hierarchies, categories, descriptions, and relations between Data Assets into SAP LeanIX, facilitating analysis of data usage and data management down to the application and interface level.
  * Map responsible owners of the data assets from Collibra to subscriptions in SAP LeanIX.
  * Map application fact sheets from SAP LeanIX to Technology Assets in Collibra Data Catalog. To learn more, see [Fact Sheet Mapping from SAP LeanIX to Collibra](https://help.sap.com/docs/leanix/ea/fact-sheet-mapping-from-sap-leanix-to-collibra?locale=en-US&state=PRODUCTION&version=CLOUD "Configure the mapping of application, business capability, and interface fact sheets from SAP LeanIX to Collibra to synchronize fields and subscriptions.").
  * Map business capability fact sheets from SAP LeanIX to Business Assets in Collibra Data Catalog. To learn more, see [Fact Sheet Mapping from SAP LeanIX to Collibra](https://help.sap.com/docs/leanix/ea/fact-sheet-mapping-from-sap-leanix-to-collibra?locale=en-US&state=PRODUCTION&version=CLOUD "Configure the mapping of application, business capability, and interface fact sheets from SAP LeanIX to Collibra to synchronize fields and subscriptions.").
  * Map interface fact sheets from SAP LeanIX to Technology Assets in Collibra Data Catalog. To learn more, see [Fact Sheet Mapping from SAP LeanIX to Collibra](https://help.sap.com/docs/leanix/ea/fact-sheet-mapping-from-sap-leanix-to-collibra?locale=en-US&state=PRODUCTION&version=CLOUD "Configure the mapping of application, business capability, and interface fact sheets from SAP LeanIX to Collibra to synchronize fields and subscriptions.").
  * Map relations between data objects, applications, business capabilities, and interface fact sheets to relations between assets in Collibra. To learn more, see [Relation Mapping from SAP LeanIX to Collibra](https://help.sap.com/docs/leanix/ea/relation-mapping-from-sap-leanix-to-collibra?locale=en-US&state=PRODUCTION&version=CLOUD "Configure the mapping of relations between fact sheets to the relation between assets to enhance data governance and lineage tracking.").
